Module popular_types

Module popular_types 

Popular type support for common Rust types. Popular type support for component model

This module provides built-in implementations of Assign trait for commonly used Rust types to eliminate manual implementation boilerplate and improve developer experience.

Modules

std_types
Standard library type support

Traits

PopularType
Marker trait to identify types that should get popular type support