Component model macro support
Derive Macros
- Assign
- Derives the
Assigntrait for struct fields, allowing each field to be set with a value that can be converted into the field’s type. - Component
From - Macro to implement
Fromfor each component (field) of a structure. This macro simplifies the creation ofFromtrait implementations for struct fields, enabling easy conversion from a struct reference to its field types. - Component
Model - Unified derive macro that combines all component model functionality into a single annotation.
- Components
Assign - Derives the
ComponentsAssigntrait for a struct, enablingcomponents_assignwhich set all fields at once. - From
Components - A procedural macro to automatically derive the
From< T >trait implementation for a struct, enabling instances of one type to be converted from instances of another type.