Popular type support for common Rust types. Popular type support for component model
This module provides built-in implementations of Assign trait for commonly used Rust types
to eliminate manual implementation boilerplate and improve developer experience.
Modules
- std_
types - Standard library type support
Traits
- Popular
Type - Marker trait to identify types that should get popular type support